#
# spec file for package gigolo
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gigolo
Version:        0.5.4
Release:        1.3
Summary:        Frontend to Manage Connections to Remote Filesystems
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://git.xfce.org/apps/gigolo/
Source0:        https://archive.xfce.org/src/apps/gigolo/0.5/%{name}-%{version}.tar.bz2
BuildRequires:  gettext >= 0.19.8
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gio-2.0) >= 2.38.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14.0
# uses xdg-open
Requires:       xdg-utils
Recommends:     %{name}-lang = %{version}

%description
Gigolo is a frontend to manage connections to remote filesystems using
GIO/GVFS. It allows connecting/mounting remote filesystems and manage

%lang_package

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

# remove documentation/license files included below
rm -rf %{buildroot}%{_datadir}/doc

%suse_update_desktop_file -i %{name} System GTK Filesystem

%find_lang %{name}

%files
%license COPYING
%doc AUTHORS NEWS README.md THANKS TODO
%doc %{_mandir}/man1/gigolo.1*
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/org.xfce.gigolo.*

%files lang -f %{name}.lang

%changelog
* Mon Dec 30 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.5.4
  * Update copyright year
  * I18n: Update po/LINGUAS list
  * Added missing Keywords entry to .desktop file
  * build: Use XDT_VERSION_INIT
  * build: Switch from intltool to gettext
  * build: Add #ifdef around bind_textdomain_codeset
  * build: Define our own windowing macro instead of extending GDK's
  * Translation Updates
* Fri Sep 29 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.5.3
  * Update copyright year and urls
  * Replace remaining stock icons
  * Replace (some) deprecated stock icons
  * Fix double free
  * Fix compiler warning -Wmaybe-uninitialized
  * Disable systray icon outside X11
  * Detect DE using XDG_CURRENT_DESKTOP (Fixes #19)
  * Add icons at missing sizes, clean up SVG metadata
  * build: Use XDT_CHECK_PACKAGE
  * build: Fix autotools warnings
  * Update `.gitignore`
  * Rename "SSH" to "SSH / SFTP"
  * Fix intltool lock file issue during make distcheck
  * Update TODO
  * Refresh Glade file, drop unused tab labels (fixes #13)
  * move the logic setting GtkSpin port value to setup_for_type()
  * Use new icon in window titlebar
  * Fix compilation warnings
  * autoconf: Some updates
  * Only show an error dialog if the host field is visible/required
  * Remove capitalization from icon name
  * Update GenericName (#2)
  * Fix comment style.
  * Remove GSourceFunc casts
  * Update Makefile.am
  * Add gigolo.ui to POTFILES.in (Issue #6)
  * Added new icons following new style and reverse DNS format.
  * Add new README.md and update AM_INIT_AUTOMAKE
  * Add basic GitLab pipeline
  * Bug #16717: Move from exo-csource to xdt-csource
  * Translation Updates
* Wed Mar 24 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.2
  * Refresh Glade file, drop unused tab labels (gxo#apps/gigolo#13)
  * move the logic setting GtkSpin port value to setup_for_type()
    (gxo#apps/gigolo#11)
  * Use new icon in window titlebar
  * Fix compilation warnings
  * autoconf: Some updates
  * Only show an error dialog if the host field is visible/required
  * Remove capitalization from icon name
  * Update GenericName (gxo#apps/gigolo#2)
  * Fix comment style.
  * Remove GSourceFunc casts
  * Update Makefile.am
  * Add gigolo.ui to POTFILES.in (gxo#apps/gigolo#6)
  * Added new icons following new style and reverse DNS format.
  * Add new README.md and update AM_INIT_AUTOMAKE
  * Add basic GitLab pipeline
  * bxo#16717: Move from exo-csource to xdt-csource
  * Translation Updates
* Sat Mar 14 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.5.1
  * Fixes an annoying bug about wrong port being saved in the bookmark
    when saving it (bxo#15455 boo#1155611)
* Tue Aug 13 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.5.0
  * Stable GTK+3 release
  * Migrate gvfs commands to gio
  * Set port number when connection type changes
  * Only ask for share name if the field is shown/mandatory (bxo#14928)
  * Improved appearance of various dialogs
  * Improved sizings of the icon view
  * Updated translations
- Cleaned up spec file
- Only use NEWS as changelog
* Wed Dec  5 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Regression in 0.4.90 (bxo#14928)
- Revert to 0.4.2 version to preserve functionalties.
* Fri Nov 30 2018 Stefan Seyfried <seife+obs@b1-systems.com>
- more explicit gtk3 dependency specification
- Leap 42.3 does not build anymore, remove obsolete %%post*-snippets
* Fri Nov 30 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Gigolo 0.4.90
  * Port to GTK+ 3
  * Improved appearance of various dialogs
  * Improved sizings of the icon view
  * Updated translations-
- Cleaned spec file
- Use system icon for better integration
* Thu Jan  9 2014 gber@opensuse.org
- update to version 0.4.2
  - Fix mnemonics in the Connect dialog.
  - Resolve symbolic links before writing config files.
  - Remember side panel position.
  - Store and display colours for bookmarks.
  - Allow editing bookmarks from the main window popup menu.
  - Do not set the colour when no colour is explicitly selected.
  - Add a separator to the Bookmark Edit Dialog.
  - Don't show errors we are not supposed to show.
  - Automatically choose the first Samba share if any were found.
  - Add 'Open in Terminal' command.
  - Remove some set but unused variables.
  - Display bookmark name in the connection list if the connection
    has a bookmark.
  - Do not make the Connect button insensitive, never (bug #8103).
  - Improve WebDav URI handling.
  - Validate an entered custom URI by trying to parse it.
  - After creating/editing a bookmark, update the list of mounts.
  - Fix WebDav path parsing when there is no path.
  - Add new command-line option to auto connect bookmarks.
  - Drop Waf build system support and just use autotools.
  - Translation updates
- drop gigolo-desktop.patch and edit desktop file in-place instead
* Sun Apr 29 2012 gber@opensuse.org
- added dependency on xdg-utils since xdg-open is used
- require gvfs, gigolo does not make much sense without it
* Fri Mar 30 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- build using autotools rather than waf
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Feb 17 2011 gber@opensuse.org
- call %%desktop_database_post/un
* Sat Jan 15 2011 gber@opensuse.org
- do not require but recommend -lang subpackage
* Thu Dec 23 2010 gber@opensuse.org
- fix waf usage
  * use $RPM_OPT_FLAGS
  * show compiler output
- split off lang subpackage
* Sun Dec  5 2010 andrea@opensuse.org
-  spec file clean up, using pkgconfig for BuildRequires
* Sun Oct 24 2010 andrea@opensuse.org
- update to 0.4.1
  * Use SSH/SFTP as default connection type for new
    bookmarks/connections
  * Allow finishing the Connect / Bookmark Edit dialog by
    pressing Enter
  * Improve build system to respect LINGUAS environment variable
  * Show an error message dialog if the file-manager command failed
    to execute
  * Remove the preference to select the Volume Manager
    implementation
  * Many minor fixes and improvements
- remove unsopported locale
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 0.4.0
  * Support mounting volumes like local partitions
  * WebDav URIs may have an optional path argument
  * Add a folder property for bookmarks which is used to open the file
    manager with this folder
  * Add a Bookmark side panel
  * Many minor fixes and improvements
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 0.3.2
  * Improve the network browsing code to poperly auto-mount Samba
    resources for browsing if necessary
  * Updated translations
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 0.3.1
  * Fix build with GTK 2.12
  * Show the main window when the status icon in the notification
    area gets removed
* Fri Apr  3 2009 prusnak@suse.cz
- updated to 0.3.0
  * Add a 'Browse Network' side panel to browse for available
    Samba/Windows network shares.
  * Detect an already running instance and show its window instead of
    starting a new instance.
  * Add command line option "--new-instance" ("-i") to restore the old
    behaviour.
  * Use the GtkMountOperation dialog when additional authentication
    information are needed. This implicitly allows choosing the method
    to store passwords (never, session, forever).
  * Minimise to tray when the close button is clicked instead of when
    minimising the main window.
  * Add a new preference to set whether to show error message dialogs
    when auto-connecting bookmarks.
  * Various fixes and improvements to URI handling.
  * Add a View menu to quickly change GUI preferences.
  * Add Online Help and Supported Protocols help menu items.
* Mon Feb 23 2009 prusnak@suse.cz
- updated to 0.2.1.
  * Fix wrong saving of Obex URIs
  * Fix always disabled 'Create Bookmark' menu item
  * Escape the userinfo part of URIs to allow at-signs.
* Tue Feb 17 2009 prusnak@suse.cz
- created package (version 0.2.0)
